# RideSims
 
A python package for running ride sequence automation scripts for RideSims.

----

## Working with Poetry

The commands listed below can be used to install, build, and run the package using Poetry.


Add a library to the dependencies:

```
$ poetry add <package>
```


Install the package with its dependencies:

```
$ poetry install
```


Create a wheel package:

```
$ poetry build
```


Test the wheel package:

```
$ pip install --user /ridesims/dist/ridesims-0.1.0-py3-none-any.whl
```

----

## Meet the Rides

[Everest 🏔](.\ridesims\rides\Everest\README.md)

[Splash Mountain 🐰](.\ridesims\rides\SplashMountain\README.md)

...


----
